/* Log Messages */
function log(msg) {
  var log = document.querySelector('section#log>ol');
  var newItem = document.createElement('li');
  var now = new Date();
  newItem.innerHTML = now.toLocaleTimeString() + ': <em>' + msg + '</em>';
  log.appendChild(newItem);
}

/* Remove item from list */
function removeFromList(e) {
  var item = e.currentTarget.parentNode;
  item.remove();
  log(item.title + ' removed.');

  // Check if list item being removed is in common list items
  //  If it is, we need to enable its button there.
  var selector = '#common-items-list>li>button[name="' + item.title + '"]';
  var btnMatch = document.querySelector(selector);
  if (btnMatch) {
    btnMatch.disabled = false;
  }
}

/* Add product to list */
function addToList(product) {
  product = product.trim();

  // Check if list item is already in active list
  //  or if product is empty string.
  var selector = '#active-items-list>li[title="' + product + '"]';
  var btnMatch = document.querySelector(selector);
  if (btnMatch || !product.length) {
    return false;
  }
  var activeList = document.getElementById('active-items-list');
  var newItem = document.createElement('li');
  newItem.title = product;
  newItem.innerHTML = product + ' ';
  activeList.appendChild(newItem);
  log(product + ' added.');

  var btnRemove = document.createElement('button');
  btnRemove.innerHTML = '-';
  btnRemove.addEventListener('click', removeFromList);
  newItem.appendChild(btnRemove);

  // Check if list item being added is in common list items
  // If it is, we need to disable its button there.
  var selector = '#common-items-list>li>button[name="' + product + '"]';
  var btnMatch = document.querySelector(selector);
  if (btnMatch) {
    btnMatch.disabled = true;
  }
}

function init() {
  log('Page Loaded');
  var btnListAdd = document.getElementsByClassName('btn-add');
  var btnAddNewItem = document.getElementById('add-new-item');
  var newItem = document.getElementById('new-item');
  newItem.focus();

  /* Add event listeners to all common list Add buttons */
  for (btn of btnListAdd) {
    btn.addEventListener('click', function(e) {
      var button = e.currentTarget;
      var product = button.name;
      addToList(product);
    });
  }

  /* Add event listener to New Item Add button */
  btnAddNewItem.addEventListener('click', function() {
    addToList(newItem.value);
    newItem.value='';
    newItem.focus();
  });

  /* 
    Add event listener capturing Enter press while
    focus is on New Item field 
  */
  newItem.addEventListener('keypress', function(e) {
    if (e.key === 'Enter') {
      addToList(newItem.value);
      newItem.value='';
      newItem.focus();
    }
  });
}

window.addEventListener("load", init);